import {createRouter, createWebHistory} from 'vue-router'
import Login from '@/components/auth/Login.vue'
import Error from '@/components/info/Error.vue'
import Monitoring from "@/views/Monitoring.vue"
import store from '@/store/store.js'
import Summary from "@/views/Summary.vue";

const router = createRouter({
    history: createWebHistory(import.meta.env.BASE_URL),
    routes: [
        {
            path: '/',
            name: 'root',
            beforeEnter: (to, from, next) => {
                // 만약 로그인이 되어있다면 Summary 페이지로 바로 이동시켜라
                if (isAuthenticated()) {
                    return next('/summary');
                } else {
                    return next('/login');
                }
            }
        },
        {
            path: '/login',
            name: 'login',
            component: Login,
            beforeEnter: (to, from, next) => {
                // 만약 로그인이 되어있다면 Summary 페이지로 바로 이동시켜라
                if (isAuthenticated()) {
                    return next('/summary');
                } else {
                    // 아니면 그대로
                    next();
                }
            }

        },
        {
            path: '/summary',
            name: 'summary',
            component: Summary,
            // 중복되는 beforeEnter 함수 재사용 가능
            beforeEnter: (to, from, next) => {
                // 만약 로그인이 되어있다면 localStorage 안에 loginInfo 를 parse 로 들고와서 setUserData 에 넣어라
                if (isAuthenticated()) {
                    store.commit("setUserData", JSON.parse(localStorage.getItem('loginInfo')));
                    next();
                    // 아니면 login 페이지로 이동시켜라
                } else {
                    return next('/login');
                }
            }
        },
        {
            path: '/monitoring',
            name: 'Monitoring',
            component: Monitoring,
            // 중복되는 beforeEnter 함수 재사용 가능
            beforeEnter: (to, from, next) => {
                // 만약 로그인이 되어있다면 localStorage 안에 loginInfo 를 parse 로 들고와서 setUserData 에 넣어라
                if (isAuthenticated()) {
                    store.commit("setUserData", JSON.parse(localStorage.getItem('loginInfo')));
                    next();
                    // 아니면 login 페이지로 이동시켜라
                } else {
                    return next('/login');
                }

            }
        },
        {
            path: '/error',
            name: 'error',
            component: Error,
        }
    ]
});


// 로그인 이후 들어오는 모든 하위 페이지 각각 getItem 모두 적용 : 모든 페이지에서 새로고침시 로그인이 유지되도록
function isAuthenticated() {
    return localStorage.getItem('loginInfo')
}

export default router
