import {createStore} from 'vuex'
import {login, logout} from "@/store/fetchData.js";
import CryptoJS from "crypto-js";
import router from '@/router';

const store = createStore({
    state() {
        return {
            isLoading: true,
            user: {},
            tableColumns: [
                "Pipeline Name",
                "Module Name",
                "Module Type",
                "Table Name",
                "Table Map",
                "Insert",
                "Update",
                "Delete",
                "Discard",
                "Filtered"
            ],
            moduleColumns: [
                {name: "All", value: ""},
                {name: "Extract", value: "Extract"},
                {name: "Send", value: "Send"},
                {name: "Post", value: "Post"}
            ],
            errorMessage: "",
        }
    },

    actions: {
        async getUser(store, {id, password}) {

            const passwordHash = CryptoJS.SHA256(password).toString().toUpperCase()
            const loginData = {
                id: id,
                password: passwordHash
            }

            try {
                const response = await login(loginData);

                if (response && response.status === 200) {
                    this.commit("setUserData", response.data.data.user);

                    const loginInfoStr = JSON.stringify(response.data.data.user);
                    await localStorage.setItem('loginInfo', loginInfoStr);
                    router.push('/summary');
                }


            } catch (error) {

                router.push('/error')

                const response = error.response;
                this.commit("setErrorMessage", response.data.errorMessage);

            }
        },


        async clearUser() {
            const response = await logout();

            if (response.status === 200) {
                this.commit("setUserData", {});
                localStorage.removeItem("loginInfo");
                router.push('/login')
            } else {
                router.push('/error')
            }
        },

    },

    mutations: {
        setUserData(state, userData) {
            state.user = userData;
        },
        setErrorMessage(state, message) {
            state.errorMessage = message;
        },

        setLoading(state, isLoading) {
            state.isLoading = isLoading
        },

    },

    getters: {
        isLoading(state) {
            return state.isLoading
        },

        getAccessToken(state) {
            return state.user.info.accessToken
        }
    }

})

export default store;